summaryrefslogtreecommitdiffstats
path: root/src/bookmarkssidebarpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkssidebarpage.cpp')
-rw-r--r--src/bookmarkssidebarpage.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/bookmarkssidebarpage.cpp b/src/bookmarkssidebarpage.cpp
index 7ffa321..af39d7e 100644
--- a/src/bookmarkssidebarpage.cpp
+++ b/src/bookmarkssidebarpage.cpp
@@ -35,8 +35,8 @@
#include "dolphinview.h"
#include "editbookmarkdialog.h"
-BookmarksSidebarPage::BookmarksSidebarPage(TQWidget* tqparent) :
- SidebarPage(tqparent)
+BookmarksSidebarPage::BookmarksSidebarPage(TQWidget* parent) :
+ SidebarPage(parent)
{
TQVBoxLayout* tqlayout = new TQVBoxLayout(this);
m_bookmarksList = new BookmarksListBox(this);
@@ -194,8 +194,8 @@ void BookmarksSidebarPage::adjustSelection(const KURL& url)
int maxLength = 0;
int selectedIndex = -1;
// Search the bookmark which is equal to the URL or at least is a tqparent URL.
// If there are more than one possible tqparent URL candidates, choose the bookmark
// which covers the bigger range of the URL.
int i = 0;
while (!bookmark.isNull()) {
@@ -238,8 +238,8 @@ void BookmarksSidebarPage::connectToActiveView()
this, TQT_SLOT(slotURLChanged(const KURL&)));
}
-BookmarksListBox::BookmarksListBox(TQWidget* tqparent) :
- TQListBox(tqparent)
+BookmarksListBox::BookmarksListBox(TQWidget* parent) :
+ TQListBox(parent)
{
setAcceptDrops(true);
}
@@ -194,8 +194,8 @@ void BookmarksSidebarPage::adjustSelection(const KURL& url)
int maxLength = 0;
int selectedIndex = -1;
- // Search the bookmark which is equal to the URL or at least is a tqparent URL.
- // If there are more than one possible tqparent URL candidates, choose the bookmark
+ // Search the bookmark which is equal to the URL or at least is a parent URL.
+ // If there are more than one possible parent URL candidates, choose the bookmark
// which covers the bigger range of the URL.
int i = 0;